import java.awt.*;
import java.awt.font.*;
import java.awt.geom.*;
import javax.swing.*;

public class GraphPanel extends JPanel
{
    final int
    HPAD = 60,
    VPAD = 40;
    int[] data;
    Font font;
 
    public GraphPanel()
    {
        //data = new int[] {
        //    120, 190, 211, 75, 30, 290, 182, 65, 85, 120, 100, 101, 20
        //};
        font = new Font("lucida sans regular", Font.PLAIN, 12);
        setBackground(Color.white);
        GetData();
    }
 
    public void GetData()
    {
        data = new int[DTRS_Main.numOfClass];
        //System.out.println("Getting Plot data for "+DTRS_Main.numOfClass+" classes.");        
        for (int i = 0; i < DTRS_Main.numOfClass; i++)
        {
            data[i] = DTRS_Main.myClass[i].size ;
            //System.out.println(""+data[i]);
        }
    }
    

    protected void paintComponent(Graphics g)
    {
        super.paintComponent(g);
        Graphics2D g2 = (Graphics2D)g;
        g2.setRenderingHint(RenderingHints.KEY_ANTIALIASING,
                            RenderingHints.VALUE_ANTIALIAS_ON);
        g2.setFont(font);
        FontRenderContext frc = g2.getFontRenderContext();
        
        int w = getWidth();
        int h = getHeight();
        // scales
        int points = 40 ;
        float xInc = (w - HPAD - VPAD) / points;
        float yInc = (h - 2*VPAD) / 10f;
        int[] dataVals = getDataVals();
        //float yScale = dataVals[2] / 10f;
        //float yScale = DTRS_Main.numOfObjects / 10f;
        float yScale = DTRS_Main.numOfObjects / 10f;
 
        // ordinate
        g2.draw(new Line2D.Double(HPAD, VPAD, HPAD, h - VPAD));
        // tic marks
        float x1 = HPAD, y1 = VPAD, x2 = HPAD - 3, y2;
        for(int j = 0; j <= DTRS_Main.numOfObjects; j++)
        {
            g2.draw(new Line2D.Double(x1, y1, x2, y1));
            y1 += yInc;
        }
        // y-axis labels
        String text; LineMetrics lm;
        float xs, ys, textWidth, height;
        for(int j = 0; j < DTRS_Main.numOfObjects; j++)
        {
            //text = String.valueOf(dataVals[1] - (int)(j * yScale));
            text = String.valueOf(DTRS_Main.numOfObjects - (int)(j * yScale));
            textWidth = (float)font.getStringBounds(text, frc).getWidth();
            lm = font.getLineMetrics(text, frc);
            height = lm.getAscent();
            xs = HPAD - textWidth - 7;
            ys = VPAD + (j * yInc) + height/2;
            g2.drawString(text, xs, ys);
        }
 
        // abcissa
        g2.draw(new Line2D.Double(HPAD, h - VPAD, w - VPAD, h - VPAD));
        
        // tic marks
        x1 = HPAD; y1 = h - VPAD; y2 = y1 + 3;
        for(int j = 0; j < points; j++)
        {
            g2.draw(new Line2D.Double(x1, y1, x1, y2));
            x1 += xInc;
        }
        // x-axix labels
        ys = h - VPAD;
        for(int j = 0; j < points+1; j++)
        {
            if(j %2 == 0)
            {
                text = String.valueOf((float)j /points);

                textWidth = (float)font.getStringBounds(text, frc).getWidth();
                lm = font.getLineMetrics(text, frc);
                height = lm.getHeight();
                xs = HPAD + j * xInc - textWidth/2;
                g2.drawString(text, xs, ys + height);
            }
        }
 
        // plot data
        x1 = HPAD;
        //yScale = (float)(h - 2*VPAD) / dataVals[2];
        yScale = (float)(h - 2*VPAD) / DTRS_Main.numOfObjects;
        
        int count = 0 ;
        int totaln = 0 ;
        int totalb = 0 ;
        int totalp = 0 ;
        
        for(int j=1; j <= points; j++)
        {
            //for(int k=0; k < DTRS_Main.numOfClass; k++)
            for(int k=0; k < DTRS_Main.numOfClass; k++)    
            {
                if((DTRS_Main.myClass[k].CPr <= ((float)j / points)) && (DTRS_Main.myClass[k].CPr > ((float)(j-1) / points)))
                {
                    //count++ ;
                    count += DTRS_Main.myClass[k].size ;
                }
                if(j == 1)
                {
                    if(DTRS_Main.myClass[k].CPr == ((float)0))
                    {
                        count += DTRS_Main.myClass[k].size ;
                    }
                }
            }
            if(((float)j/points)<=DTRS_Main.beta)
            {
                g2.setColor(new Color(250,20,20));
                totaln += count ;
            }
            else if(((float)j/points)>DTRS_Main.alpha)
            {
                g2.setColor(new Color(20,250,20));
                totalp += count ;
            }
            else
            {
                g2.setColor(new Color(20,20,250));
                totalb += count ;
            }
            
            g2.fillRect((int)(HPAD+((j-1)*xInc)),(int)((h-VPAD)-count*yScale),(int)xInc,(int)(count*yScale));
            g2.draw(new Rectangle2D.Double(HPAD+((j-1)*xInc),(h-VPAD)-count*yScale,xInc,count*yScale));
            count = 0 ;
        }
        g2.setColor(new Color(0,0,0));
        
        Font font2 = new Font("lucida sans regular", Font.PLAIN, 20);
        g2.setFont(font2);
        FontRenderContext frc2 = g2.getFontRenderContext();
        
        text = "\u03b2";
        textWidth = (float)font.getStringBounds(text, frc2).getWidth();
        lm = font.getLineMetrics(text, frc2);
        height = lm.getAscent();
        xs = HPAD + (DTRS_Main.beta*points) * xInc - 5;
        ys = VPAD - 5;
        g2.drawString(text, xs, ys);

        text = "\u03b1";
        textWidth = (float)font.getStringBounds(text, frc2).getWidth();
        lm = font.getLineMetrics(text, frc2);
        height = lm.getAscent();
        xs = HPAD + (DTRS_Main.alpha*points) * xInc - 5;
        ys = VPAD - 5;
        g2.drawString(text, xs, ys);
        
        g2.draw(new Line2D.Double(HPAD + (DTRS_Main.beta*points) * xInc,VPAD,HPAD + (DTRS_Main.beta*points) * xInc,h - VPAD));
        g2.draw(new Line2D.Double(HPAD + (DTRS_Main.alpha*points) * xInc,VPAD,HPAD + (DTRS_Main.alpha*points) * xInc,h - VPAD));
        
        g2.setColor(new Color(250,20,20));
        g2.draw(new Line2D.Double(HPAD,(h-VPAD)-totaln*yScale,HPAD + (DTRS_Main.beta*points) * xInc,(h-VPAD)-totaln*yScale));
        g2.setColor(new Color(20,20,250));
        g2.draw(new Line2D.Double(HPAD + (DTRS_Main.beta*points) * xInc,(h-VPAD)-totalb*yScale,HPAD + (DTRS_Main.alpha*points) * xInc,(h-VPAD)-totalb*yScale));
        g2.setColor(new Color(20,250,20));
        g2.draw(new Line2D.Double(HPAD + (DTRS_Main.alpha*points) * xInc,(h-VPAD)-totalp*yScale,w - VPAD,(h-VPAD)-totalp*yScale));

    }
 
    private int[] getDataVals()
    {
        int max = Integer.MIN_VALUE;
        int min = Integer.MAX_VALUE;
        for(int j = 0; j < data.length; j++)
        {
            if(data[j] < min)
                min = data[j];
            if(data[j] > max)
                max = data[j];
        }
        int span = max - min;
        return new int[] { min, max, span };
    }
}
